==> apache-impala-3.4.2.tar.gz: apache-impala-3.4.2/fe/src/main/java/org/apache/impala/analysis/AnalysisUtils.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.impala.analysis;

import org.apache.impala.common.AnalysisException;

import java.util.Collection;

class AnalysisUtils {

  static <T> void throwIfNotNull(T o, String message) throws AnalysisException {
    if (o != null) throw new AnalysisException(message);
  }

  static void throwIfNotEmpty(Collection<?> c, String message)
      throws AnalysisException {
    if (c != null && !c.isEmpty()) throw new AnalysisException(message);
  }

  static <T> void throwIfNull(T o, String message) throws AnalysisException {
    if (o == null) throw new AnalysisException(message);
  }

  static void throwIfNullOrEmpty(Collection<?> c, String message)
      throws AnalysisException {
    if (c == null || c.isEmpty()) throw new AnalysisException(message);
  }
}

==> apache-impala-4.3.0.tar.gz: apache-impala-4.3.0/fe/src/main/java/org/apache/impala/analysis/AnalysisUtils.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.impala.analysis;

import org.apache.impala.common.AnalysisException;

import java.util.Collection;

class AnalysisUtils {

  static <T> void throwIfNotNull(T o, String message) throws AnalysisException {
    if (o != null) throw new AnalysisException(message);
  }

  static void throwIfNotEmpty(Collection<?> c, String message)
      throws AnalysisException {
    if (c != null && !c.isEmpty()) throw new AnalysisException(message);
  }

  static <T> void throwIfNull(T o, String message) throws AnalysisException {
    if (o == null) throw new AnalysisException(message);
  }

  static void throwIfNullOrEmpty(Collection<?> c, String message)
      throws AnalysisException {
    if (c == null || c.isEmpty()) throw new AnalysisException(message);
  }

  static void throwIfTrue(boolean cond, String message)
      throws AnalysisException {
    if (cond) throw new AnalysisException(message);
  }
}
